==> BgChat-Ircd-1.4.tar.gz: BgChat-Ircd/modules/m_svshint.c <==
/************************************************************************
 *   IRC - Internet Relay Chat, modules/m_version.c
 *   Copyright (C) 1990 Jarkko Oikarinen and
 *                      University of Oulu, Computing Center
 *
 *   See file AUTHORS in IRC package for additional names of
 *   the programmers. 
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 1, or (at your option)
 *   any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *   $Id: m_svshint.c,v 1.3 2003/04/04 03:16:20 stx Exp $
 */
#include "stdinc.h"
#include "handlers.h"
#include "client.h"
#include "common.h"		/* TRUE bleah */
#include "irc_string.h"
#include "ircd.h"
#include "hash.h"
#include "numeric.h"
#include "send.h"
#include "s_conf.h"
#include "s_log.h"
#include "s_serv.h"
#include "msg.h"
#include "parse.h"
#include "modules.h"


static void ms_svshint(struct Client *, struct Client *, int, char **);
struct Message svshint_msgtab = {
	"SVSHINT", 0, 1, 0, 0, 0, 0,
	{m_unregistered, m_ignore, ms_svshint, m_ignore}
};

#ifndef STATIC_MODULES
void
_modinit(void)
{
	mod_add_cmd(&svshint_msgtab);
}

void
_moddeinit(void)
{
	mod_del_cmd(&svshint_msgtab);
}

char *_version = "20031228_1";
#endif
/*
 * ms_svshint - SVSHINT command handler
 *      parv[0] = sender prefix
 *      parv[1] = hint flags
 *      parv[2] = nick
 */
static void
ms_svshint(struct Client *client_p, struct Client *source_p, int parc, char *parv[])
{
	struct Client *victim;
	unsigned int hint;

	if(parc < 4)
		return;

	victim = find_client(parv[2]);

	if(!IsServer(source_p))
		return;

	if(!(victim))
		return;

	if(!strcasecmp(parv[1], "NSID"))
	{

		if(!strcasecmp(parv[3], "1"))
		{
			SetNSId(victim);
			CurrentIdentUsers++;

			if(CurrentIdentUsers > MaxIdentUsers)
				MaxIdentUsers = CurrentIdentUsers;

		}
		else
		{
			ClearNSId(victim);
			CurrentIdentUsers--;

			if(CurrentIdentUsers < 0)
				CurrentIdentUsers = 0;
		}

		sendto_server(client_p, NULL, NOCAPS, NOCAPS,
			      ":%s SVSHINT NSID %s %s", me.name, victim->name, parv[3]);
		return;
	}

	if(!strcasecmp(parv[1], "OSID") && !IsOSId(victim))
	{
		SetOSId(victim);
		CurrentOSidUsers++;

		if(CurrentOSidUsers > MaxOSidUsers)
			MaxOSidUsers = CurrentOSidUsers;

		sendto_server(client_p, NULL, NOCAPS, NOCAPS,
			      ":%s SVSHINT OSID %s 1", me.name, victim->name);
		return;
	}

	// Add nokick chan for user - stx
	if(!strcasecmp(parv[1], "NOKICK") && (parc == 5))
	{
		if(strcmp(parv[4], "1") == 0)
			add_nokick_chan(victim, parv[3]);

		else
			del_nokick_chan(victim, parv[3]);

		sendto_server(client_p, NULL, NOCAPS, NOCAPS,
			      ":%s SVSHINT NOKICK %s %s %s", me.name, victim->name, parv[3],
			      parv[4]);
		return;
	}

	// Gliner identified - stx
	if(!strcasecmp(parv[1], "NK"))
	{
		ilog(L_ALL, "Adding GLiner ID for %s", victim->name);
		SetGLId(victim);

		CurrentGlinerUsers++;

		if(CurrentGlinerUsers > MaxGlinerUsers)
			MaxGlinerUsers = CurrentGlinerUsers;

		sendto_server(client_p, NULL, NOCAPS, NOCAPS,
			      ":%s SVSHINT NK %s 1", me.name, victim->name);
		return;
	}


}

==> BgChat-Ircd-1.6.tar.gz: BgChat-Ircd/modules/m_svshint.c <==
/************************************************************************
 *   IRC - Internet Relay Chat, modules/m_version.c
 *   Copyright (C) 1990 Jarkko Oikarinen and
 *                      University of Oulu, Computing Center
 *   BgChat Develops Haker4o
 *   $Id: m_svshint.c,v 1.3 2004/06/01 03:16:20 haker4o Exp $
 */
#include "stdinc.h"
#include "handlers.h"
#include "client.h"
#include "common.h"		/* TRUE bleah */
#include "irc_string.h"
#include "ircd.h"
#include "hash.h"
#include "numeric.h"
#include "send.h"
#include "s_conf.h"
#include "s_log.h"
#include "s_serv.h"
#include "msg.h"
#include "parse.h"
#include "modules.h"


static void ms_svshint(struct Client *, struct Client *, int, char **);
struct Message svshint_msgtab = {
	"SVSHINT", 0, 1, 0, 0, 0, 0,
	{m_unregistered, m_ignore, ms_svshint, m_ignore}
};

#ifndef STATIC_MODULES
void
_modinit(void)
{
	mod_add_cmd(&svshint_msgtab);
}

void
_moddeinit(void)
{
	mod_del_cmd(&svshint_msgtab);
}

char *_version = "20031228_1";
#endif
/*
 * ms_svshint - SVSHINT command handler
 *      parv[0] = sender prefix
 *      parv[1] = hint flags
 *      parv[2] = nick
 */
static void
ms_svshint(struct Client *client_p, struct Client *source_p, int parc, char *parv[])
{
	struct Client *victim;
	unsigned int hint;

	if(parc < 4)
		return;

	victim = find_client(parv[2]);

	if(!IsServer(source_p))
		return;

	if(!(victim))
		return;

	if(!strcasecmp(parv[1], "NSID"))
	{

		if(!strcasecmp(parv[3], "1"))
		{
			SetNSId(victim);
			CurrentIdentUsers++;

			if(CurrentIdentUsers > MaxIdentUsers)
				MaxIdentUsers = CurrentIdentUsers;

		}
		else
		{
			ClearNSId(victim);
			CurrentIdentUsers--;

			if(CurrentIdentUsers < 0)
				CurrentIdentUsers = 0;
		}

		sendto_server(client_p, NULL, NOCAPS, NOCAPS,
			      ":%s SVSHINT NSID %s %s", me.name, victim->name, parv[3]);
		return;
	}

	if(!strcasecmp(parv[1], "OSID") && !IsOSId(victim))
	{
		SetOSId(victim);
		CurrentOSidUsers++;

		if(CurrentOSidUsers > MaxOSidUsers)
			MaxOSidUsers = CurrentOSidUsers;

		sendto_server(client_p, NULL, NOCAPS, NOCAPS,
			      ":%s SVSHINT OSID %s 1", me.name, victim->name);
		return;
	}

	// Add nokick chan for user 
	if(!strcasecmp(parv[1], "NOKICK") && (parc == 5))
	{
		if(strcmp(parv[4], "1") == 0)
			add_nokick_chan(victim, parv[3]);

		else
			del_nokick_chan(victim, parv[3]);

		sendto_server(client_p, NULL, NOCAPS, NOCAPS,
			      ":%s SVSHINT NOKICK %s %s %s", me.name, victim->name, parv[3],
			      parv[4]);
		return;
	}

	// Gliner identified 
	if(!strcasecmp(parv[1], "NK"))
	{
		ilog(L_ALL, "Adding GLiner ID for %s", victim->name);
		SetGLId(victim);

		CurrentGlinerUsers++;

		if(CurrentGlinerUsers > MaxGlinerUsers)
			MaxGlinerUsers = CurrentGlinerUsers;

		sendto_server(client_p, NULL, NOCAPS, NOCAPS,
			      ":%s SVSHINT NK %s 1", me.name, victim->name);
		return;
	}

         // Stats Services identified 
	if(!strcasecmp(parv[1], "ST"))
	{
		ilog(L_ALL, "Adding Stats ID for %s", victim->name);
		SetSTId(victim);

		CurrentStatsUsers++;

		if(CurrentStatsUsers > MaxStatsUsers)
			MaxStatsUsers = CurrentStatsUsers;

		sendto_server(client_p, NULL, NOCAPS, NOCAPS,
			      ":%s SVSHINT ST %s 1", me.name, victim->name);
		return;
	}
}
